@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 A simple custom backend with an output port type which prints messages
 to stdout.
@@ -18,7 +22,7 @@ class Output(BaseOutput):
         if self.name is None:
             self.name = device['name']
         elif self.name != device['name']:
-            raise ValueError('unknown port {!r}'.format(self.name))
+            raise ValueError(f'unknown port {self.name!r}')
 
     def _send(self, message):
         print(message)
