@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 Experimental backend for rtmidi-python:
 
@@ -16,8 +20,8 @@ http://github.com/superquadratic/rtmidi-python
 Other than that, it works exactly like the included python-rtmidi
 backend.
 """
-from __future__ import absolute_import
 import rtmidi_python as rtmidi
+
 from mido.ports import BaseInput, BaseOutput
 
 
@@ -37,7 +41,7 @@ def get_devices():
     return devices
 
 
-class PortCommon(object):
+class PortCommon:
     def _open(self, virtual=False, callback=None):
         opening_input = hasattr(self, 'receive')
 
@@ -49,6 +53,7 @@ class PortCommon(object):
                     self._parser.feed(message)
                     for message in self._parser:
                         callback(message)
+
                 self._rt.callback = self._callback = callback_wrapper
                 self._has_callback = True
             else:
@@ -61,7 +66,7 @@ class PortCommon(object):
 
         if virtual:
             if self.name is None:
-                raise IOError('virtual port must have a name')
+                raise OSError('virtual port must have a name')
             self._rt.open_virtual_port(self.name)
         else:
             if self.name is None:
@@ -69,13 +74,13 @@ class PortCommon(object):
                 # In RtMidi, the default port is the first port.
                 try:
                     self.name = ports[0]
-                except IndexError:
-                    raise IOError('no ports available')
+                except IndexError as ie:
+                    raise OSError('no ports available') from ie
 
             try:
                 port_id = ports.index(self.name)
-            except ValueError:
-                raise IOError('unknown port {!r}'.format(self.name))
+            except ValueError as ve:
+                raise OSError(f'unknown port {self.name!r}') from ve
 
             self._rt.open_port(port_id)
 
@@ -89,7 +94,7 @@ class Input(PortCommon, BaseInput):
     # Todo: sysex messages do not arrive here.
     def _receive(self, block=True):
         if self._has_callback:
-            raise IOError('a callback is currently set for this port')
+            raise OSError('a callback is currently set for this port')
 
         while True:
             (message, delta_time) = self._rt.get_message()
