@@ -1,15 +1,20 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 Create a new MIDI file with some random notes.
 
 The file is saved to test.mid.
 """
-from __future__ import division
 import random
 import sys
-from mido import Message, MidiFile, MidiTrack, MAX_PITCHWHEEL
 
-notes = [64, 64+7, 64+12]
+from mido import MAX_PITCHWHEEL, Message, MidiFile, MidiTrack
+
+notes = [64, 64 + 7, 64 + 12]
 
 outfile = MidiFile()
 
