@@ -1,6 +1,11 @@
-#!/usr/bin/env python
-import sys
+#!/usr/bin/env python3
+
+# SPDX-FileCopyrightText: 2020 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 import argparse
+
 import mido
 
 
