@@ -1,14 +1,19 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 Receive messages on the input port and print messages with a specific
 channel (defaults to 0).
 
 Usage:
 
-    python example_input_filter.py portname [CHANNEL] [...]
+    python3 example_input_filter.py portname [CHANNEL] [...]
 """
-from __future__ import print_function
 import sys
+
 import mido
 
 
@@ -22,16 +27,16 @@ def accept_notes(port):
 if len(sys.argv) > 1:
     portname = sys.argv[1]
 else:
-    portname = None   # Use default port
+    portname = None  # Use default port
 
 try:
     with mido.open_input(portname) as port:
-        print('Using {}'.format(port))
+        print(f'Using {port}')
 
         print("Ignoring everything but 'note_on' and 'note_off'.")
         print('Waiting for notes...')
 
         for message in accept_notes(port):
-            print('Received {}'.format(message))
+            print(f'Received {message}')
 except KeyboardInterrupt:
     pass
