@@ -1,16 +1,16 @@
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """A port interface around a queue.
 
 This allows you to create internal ports to send messages between threads.
 """
+import queue
+
 import mido
 from mido import ports
 
-try:
-    import queue
-except ImportError:
-    # Python 2.
-    import Queue as queue
-
 
 class QueuePort(ports.BaseIOPort):
     # We don't need locking since the queue takes care of that.
