@@ -1,4 +1,9 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 Serve one or more output ports.
 
@@ -7,7 +12,7 @@ every output port.
 
 Example:
 
-    python serve_ports.py :8080 'SH-201' 'SD-20 Part A'
+    python3 serve_ports.py :8080 'SH-201' 'SD-20 Part A'
 
 This simply iterates through all incoming messages. More advanced and
 flexible servers can be written by calling the ``accept()`` and
@@ -15,6 +20,7 @@ flexible servers can be written by calling the ``accept()`` and
 an example.
 """
 import sys
+
 import mido
 from mido import sockets
 from mido.ports import MultiPort
@@ -25,5 +31,5 @@ out = MultiPort([mido.open_output(name) for name in sys.argv[2:]])
 (host, port) = sockets.parse_address(sys.argv[1])
 with sockets.PortServer(host, port) as server:
     for message in server:
-        print('Received {}'.format(message))
+        print(f'Received {message}')
         out.send(message)
