@@ -1,10 +1,16 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+
+# SPDX-FileCopyrightText: 2013 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 """
 Simple server that just prints every message it receives.
 
-    python simple_server.py localhost:8080
+    python3 simple_server.py localhost:8080
 """
 import sys
+
 from mido import sockets
 
 if sys.argv[1:]:
@@ -14,7 +20,7 @@ else:
 
 try:
     (hostname, portno) = sockets.parse_address(address)
-    print('Serving on {}'.format(address))
+    print(f'Serving on {address}')
     with sockets.PortServer(hostname, portno) as server:
         for message in server:
             print(message)
