@@ -1,6 +1,11 @@
+# SPDX-FileCopyrightText: 2017 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 from pytest import raises
-from mido.messages.specs import MIN_PITCHWHEEL, MAX_PITCHWHEEL, MIN_SONGPOS, MAX_SONGPOS
+
 from mido.messages.messages import Message, SysexData
+from mido.messages.specs import MAX_PITCHWHEEL, MAX_SONGPOS, MIN_PITCHWHEEL, MIN_SONGPOS
 
 
 def test_msg_time_equality():
@@ -89,7 +94,7 @@ def test_copy_handles_data_generator():
 
 def test_compare_with_nonmessage():
     with raises(TypeError):
-        Message('clock') == 'not a message'
+        assert Message('clock') == 'not a message'
 
 
 def test_from_dict_default_values():
@@ -112,5 +117,5 @@ def test_from_hex_sysex_data_type():
 
 def test_repr():
     msg = Message('note_on', channel=1, note=2, time=3)
-    msg_eval = eval(repr(msg))
+    msg_eval = eval(repr(msg))  # noqa: S307
     assert msg == msg_eval
