@@ -1,4 +1,9 @@
+# SPDX-FileCopyrightText: 2017 Ole Martin Bjorndalen <ombdalen@gmail.com>
+#
+# SPDX-License-Identifier: MIT
+
 from pytest import raises
+
 from mido.messages import Message
 
 
@@ -16,9 +21,3 @@ def test_encode_sysex():
     # This should not have an extra comma.
     assert str(Message('sysex', data=(1,))) == 'sysex data=(1) time=0'
     assert str(Message('sysex', data=(1, 2, 3))) == 'sysex data=(1,2,3) time=0'
-
-
-def test_encode_long_int():
-    # Make sure Python 2 doesn't stick an 'L' at the end of a long
-    # integer.
-    assert 'L' not in str(Message('clock', time=1231421984983298432948))
